# wikimedia_session
request Session for Wikimedia

##
session = MediaWikiSesson('/etc/my.yaml')

will log in using access token from file specified in my.yaml

*session.edit_token* will provide a token for posting edits
